"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@checkup/core");
const recast_1 = require("recast");
const fs = require('fs');
const ESLINT_DISABLE_REGEX = /^eslint-disable(?:-next-line|-line)*/gi;
class EslintDisableTask extends core_1.BaseTask {
    constructor() {
        super(...arguments);
        this.taskName = 'eslint-disables';
        this.taskDisplayName = 'Number of eslint-disable Usages';
        this.description = 'Finds all disabled eslint rules in a project';
        this.category = 'linting';
        this.group = 'disabled-lint-rules';
    }
    async run() {
        let jsPaths = this.context.paths.filterByGlob('**/*.js');
        let eslintDisables = await getEslintDisables(jsPaths, this.context.options.cwd);
        return core_1.sarifBuilder.fromLintResults(this, eslintDisables);
    }
}
exports.default = EslintDisableTask;
async function getEslintDisables(filePaths, cwd) {
    let data = [];
    class ESLintDisableAccumulator {
        constructor(filePath) {
            this.filePath = filePath;
            this.data = [];
        }
        add(node) {
            this.data.push({
                filePath: core_1.trimCwd(this.filePath, cwd),
                lintRuleId: 'no-eslint-disable',
                message: 'eslint-disable usages',
                line: node.loc.start.line,
                column: node.loc.start.column,
            });
        }
        get visitors() {
            let self = this;
            return {
                visitComment: function (path) {
                    if (path.value.value.trim().match(ESLINT_DISABLE_REGEX)) {
                        self.add(path.value);
                    }
                    this.traverse(path);
                },
            };
        }
    }
    await Promise.all(filePaths.map((filePath) => {
        return fs.promises.readFile(filePath, 'utf8').then((fileContents) => {
            let accumulator = new ESLintDisableAccumulator(filePath);
            let astTraverser = new core_1.AstTraverser(fileContents, recast_1.parse, recast_1.visit, {
                parser: require('recast/parsers/babel'),
            });
            astTraverser.traverse(accumulator.visitors);
            data.push(...accumulator.data);
        });
    }));
    return data;
}
//# sourceMappingURL=eslint-disable-task.js.map