"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ACCEPTED_ESLINT_CONFIG_FILES = void 0;
const path_1 = require("path");
const fs_1 = require("fs");
const core_1 = require("@checkup/core");
/**
 * @export
 * @description In prioritized order as specified by https://eslint.org/docs/user-guide/configuring
 */
exports.ACCEPTED_ESLINT_CONFIG_FILES = [
    '.eslintrc.js',
    '.eslintrc.cjs',
    '.eslintrc.yaml',
    '.eslintrc.yml',
    '.eslintrc.json',
    '.eslintrc',
];
class EslintSummaryTask extends core_1.BaseTask {
    constructor(pluginName, context) {
        super(pluginName, context);
        this.taskName = 'eslint-summary';
        this.taskDisplayName = 'Eslint Summary';
        this.description = 'Gets a summary of all eslint results in a project';
        this.category = 'linting';
        let createEslintParser = this.context.parsers.get('eslint');
        let eslintConfig = this.readEslintConfig(this.context.paths, this.context.options.cwd, this.context.pkg);
        this._eslintParser = createEslintParser(eslintConfig);
    }
    async run() {
        let report = await this._eslintParser.execute(this.context.paths.filterByGlob('**/*.js'));
        let transformedData = core_1.lintBuilder.toLintResults(report.results, this.context.options.cwd);
        let lintingErrors = core_1.groupDataByField(core_1.bySeverity(transformedData, 2), 'lintRuleId');
        let lintingWarnings = core_1.groupDataByField(core_1.bySeverity(transformedData, 1), 'lintRuleId');
        let errorsResult = lintingErrors.flatMap((lintingError) => {
            return core_1.sarifBuilder.fromLintResults(this, lintingError, {
                type: 'error',
            });
        });
        let warningsResult = lintingWarnings.flatMap((lintingWarning) => {
            return core_1.sarifBuilder.fromLintResults(this, lintingWarning, {
                type: 'warning',
            });
        });
        return [...errorsResult, ...warningsResult];
    }
    readEslintConfig(paths, basePath, pkg) {
        let eslintConfigFile = '';
        for (const acceptedConfigFile of exports.ACCEPTED_ESLINT_CONFIG_FILES) {
            let resolvedAcceptedConfigFile = path_1.join(path_1.resolve(basePath), acceptedConfigFile);
            if (paths.includes(resolvedAcceptedConfigFile)) {
                eslintConfigFile = fs_1.readFileSync(resolvedAcceptedConfigFile, { encoding: 'utf8' });
                break;
            }
        }
        if (eslintConfigFile) {
            return eslintConfigFile;
        }
        else if (pkg.eslintConfig !== null) {
            return pkg.eslintConfig;
        }
        else {
            throw new core_1.TaskError({
                taskName: this.taskName,
                taskErrorMessage: 'No eslint config found in root (in the form of .eslintrc.* or as an eslintConfig field in package.json)',
            });
        }
    }
}
exports.default = EslintSummaryTask;
//# sourceMappingURL=eslint-summary-task.js.map